==> spip_2.0.10.orig.tar.gz: spip-2.0.10.orig/ecrire/lang/public_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Entrada do web',
'articles' => 'Artigos',
'articles_auteur' => 'Artigos deste autor',
'articles_populaires' => 'Artigos m&aacute;is populares',
'articles_rubrique' => 'Artigos desta secci&oacute;n',
'aucun_article' => 'Non hai artigo neste enderezo',
'aucun_auteur' => 'Non hai autor neste enderezo',
'aucun_site' => 'Non hai web neste enderezo',
'aucune_breve' => 'Non hai breves neste enderezo',
'aucune_rubrique' => 'Non hai secci&oacute;n neste enderezo',
'autres' => 'Outras',
'autres_breves' => 'Outras breves',
'autres_groupes_mots_clefs' => 'Outros grupos de palabras chave',
'autres_sites' => 'Outros webs',

// B
'bonjour' => 'Bos d&iacute;as',
'breves' => 'Breves',

// C
'commenter_site' => 'Comentar este web',
'copie_document_impossible' => 'Resultou imposible a copia do documento',

// D
'date' => 'Data',
'dernier_ajout' => '&Uacute;ltimo engadido',
'dernieres_breves' => '&Uacute;ltimas breves',
'derniers_articles' => '&Uacute;ltimos artigos',
'derniers_commentaires' => '&Uacute;ltimos comentarios',
'derniers_messages_forum' => '&Uacute;ltimas mensaxes publicadas nos foros',
'documents_interdits_forum' => 'Os documentos est&aacute;n prohibidos no foro',

// E
'edition_mode_texte' => 'Edici&oacute;n en modo texto de',
'en_reponse' => 'En resposta a&nbsp;:',
'en_resume' => 'En resumo',
'envoyer_message' => 'Enviar unha mensaxe',
'espace_prive' => 'Espazo privado',

// F
'formats_acceptes' => 'Formatos aceptados : @formats@.',
'forum' => 'Foro',

// H
'hierarchie_site' => 'Xerarqu&iacute;a do web',

// J
'jours' => 'd&iacute;as',

// L
'lien_connecter' => 'Conectar',

// M
'meme_auteur' => 'Do mesmo autor',
'meme_rubrique' => 'Na mesma secci&oacute;n',
'memes_auteurs' => 'Dos mesmos autores',
'message' => 'Mensaxe',
'messages_forum' => 'Mensaxes do foro',
'messages_recents' => 'Mensaxes dos foros m&aacute;is recentes',
'mots_clefs' => 'Palabras chave',
'mots_clefs_meme_groupe' => 'Palabras chave dentro do mesmo grupo',

// N
'navigation' => 'Navegaci&oacute;n',
'nom' => 'Nome',
'nouveautes' => 'Novidades',
'nouveautes_web' => 'Novidades no web',
'nouveaux_articles' => 'Novos artigos',
'nouvelles_breves' => 'Novas breves',

// P
'page_precedente' => 'p&aacute;xina anterior',
'page_suivante' => 'p&aacute;xina seguinte',
'par_auteur' => 'por',
'participer_site' => 'Pode participar na vida deste web e propo&ntilde;er os seus propios artigos inscrib&iacute;ndose aqu&iacute; abaixo. Recibir&aacute; inmediatamente un correo que lle indicar&aacute; o seu c&oacute;digo de acceso ao espazo privado do web.',
'plan_site' => 'Mapa do web',
'popularite' => 'Popularidade',
'poster_message' => 'Enviar unha mensaxe',
'proposer_site' => 'Pode propo&ntilde;er un web para engadir a esta secci&oacute;n&nbsp;:',

// R
'repondre_article' => 'Responder a este artigo',
'repondre_breve' => 'Responder a esta breve',
'repondre_message' => 'Responder a esta mensaxe',
'resultats_recherche' => 'Resultados da procura',
'retour_debut_forums' => 'Volta ao principio dos foros',
'rubrique' => 'Secci&oacute;n',
'rubriques' => 'Secci&oacute;ns',

// S
'signatures_petition' => 'Sinaturas',
'site_realise_avec_spip' => 'Web realizado con SPIP',
'sites_web' => 'Sitios web',
'sous_rubriques' => 'Subsecci&oacute;ns',
'spam' => 'Correo lixo',
'suite' => 'a seguir',
'sur_web' => 'Na rede',
'syndiquer_rubrique' => 'Sindicar esta secci&oacute;n',
'syndiquer_site' => 'Sindicar todo o web',

// T
'texte_lettre_information' => 'Velaqu&iacute; a nota informativa do web',
'texte_lettre_information_2' => 'Esta nota recolle os artigos e as breves publicadas despois',

// V
'ver_imprimer' => 'Versi&oacute;n para imprimir',
'voir_en_ligne' => 'Ver en li&ntilde;a',
'voir_squelette' => 'ver o esqueleto desta p&aacute;xina'
);

?>

==> spip_2.1.orig.tar.gz: spip-2.1.orig/ecrire/lang/public_gl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://www.spip.net/trad-lang/
// ** ne pas modifier le fichier **

if (!defined("_ECRIRE_INC_VERSION")) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

// A
'accueil_site' => 'Entrada do web',
'article' => 'Article', # NEW
'articles' => 'Artigos',
'articles_auteur' => 'Artigos deste autor',
'articles_populaires' => 'Artigos m&aacute;is populares',
'articles_rubrique' => 'Artigos desta secci&oacute;n',
'aucun_article' => 'Non hai artigo neste enderezo',
'aucun_auteur' => 'Non hai autor neste enderezo',
'aucun_site' => 'Non hai web neste enderezo',
'aucune_breve' => 'Non hai breves neste enderezo',
'aucune_rubrique' => 'Non hai secci&oacute;n neste enderezo',
'auteur' => 'Auteur', # NEW
'autres' => 'Outras',
'autres_breves' => 'Outras breves',
'autres_groupes_mots_clefs' => 'Outros grupos de palabras chave',
'autres_sites' => 'Outros webs',

// B
'bonjour' => 'Bos d&iacute;as',
'breve' => 'Br&egrave;ve', # NEW
'breves' => 'Breves',

// C
'commenter_site' => 'Comentar este web',
'copie_document_impossible' => 'Resultou imposible a copia do documento',

// D
'date' => 'Data',
'dernier_ajout' => '&Uacute;ltimo engadido',
'dernieres_breves' => '&Uacute;ltimas breves',
'derniers_articles' => '&Uacute;ltimos artigos',
'derniers_commentaires' => '&Uacute;ltimos comentarios',
'derniers_messages_forum' => '&Uacute;ltimas mensaxes publicadas nos foros',
'documents_interdits_forum' => 'Os documentos est&aacute;n prohibidos no foro',

// E
'edition_mode_texte' => 'Edici&oacute;n en modo texto de',
'en_reponse' => 'En resposta a&nbsp;:',
'en_resume' => 'En resumo',
'envoyer_message' => 'Enviar unha mensaxe',
'espace_prive' => 'Espazo privado',

// F
'formats_acceptes' => 'Formatos aceptados : @formats@.',
'forum' => 'Foro',

// H
'hierarchie_site' => 'Xerarqu&iacute;a do web',

// J
'jours' => 'd&iacute;as',

// L
'lien_connecter' => 'Conectar',

// M
'meme_auteur' => 'Do mesmo autor',
'meme_rubrique' => 'Na mesma secci&oacute;n',
'memes_auteurs' => 'Dos mesmos autores',
'message' => 'Mensaxe',
'messages_forum' => 'Mensaxes do foro',
'messages_recents' => 'Mensaxes dos foros m&aacute;is recentes',
'mots_clef' => 'Mot-cl&eacute;', # NEW
'mots_clefs' => 'Palabras chave',
'mots_clefs_meme_groupe' => 'Palabras chave dentro do mesmo grupo',

// N
'navigation' => 'Navegaci&oacute;n',
'nom' => 'Nome',
'nouveautes' => 'Novidades',
'nouveautes_web' => 'Novidades no web',
'nouveaux_articles' => 'Novos artigos',
'nouvelles_breves' => 'Novas breves',

// P
'page_precedente' => 'p&aacute;xina anterior',
'page_suivante' => 'p&aacute;xina seguinte',
'par_auteur' => 'por',
'participer_site' => 'Pode participar na vida deste web e propo&ntilde;er os seus propios artigos inscrib&iacute;ndose aqu&iacute; abaixo. Recibir&aacute; inmediatamente un correo que lle indicar&aacute; o seu c&oacute;digo de acceso ao espazo privado do web.',
'plan_site' => 'Mapa do web',
'popularite' => 'Popularidade',
'poster_message' => 'Enviar unha mensaxe',
'proposer_site' => 'Pode propo&ntilde;er un web para engadir a esta secci&oacute;n&nbsp;:',

// R
'repondre_article' => 'Responder a este artigo',
'repondre_breve' => 'Responder a esta breve',
'repondre_message' => 'Responder a esta mensaxe',
'resultats_recherche' => 'Resultados da procura',
'retour_debut_forums' => 'Volta ao principio dos foros',
'rubrique' => 'Secci&oacute;n',
'rubriques' => 'Secci&oacute;ns',

// S
'signatures_petition' => 'Sinaturas',
'site_realise_avec_spip' => 'Web realizado con SPIP',
'sites_web' => 'Sitios web',
'sous_rubriques' => 'Subsecci&oacute;ns',
'spam' => 'Correo lixo',
'suite' => 'a seguir',
'sur_web' => 'Na rede',
'syndiquer_rubrique' => 'Sindicar esta secci&oacute;n',
'syndiquer_site' => 'Sindicar todo o web',

// T
'texte_lettre_information' => 'Velaqu&iacute; a nota informativa do web',
'texte_lettre_information_2' => 'Esta nota recolle os artigos e as breves publicadas despois',

// V
'ver_imprimer' => 'Versi&oacute;n para imprimir',
'voir_en_ligne' => 'Ver en li&ntilde;a',
'voir_squelette' => 'ver o esqueleto desta p&aacute;xina'
);

?>
